pub enum TerminatorKind {
Goto {
target: BlockId,
},
Switch {
data: SwitchData,
branches: IndexVec<BranchId, BlockId>,
},
Call {
call: Call,
target: BlockId,
on_unwind: BlockId,
},
Drop {
kind: DropKind,
place: Place,
fn_ptr: FnPtr,
target: BlockId,
on_unwind: BlockId,
},
InlineAsm {
asm: InlineAsm,
fallthrough: Option<BlockId>,
labels: IndexVec<BranchId, BlockId>,
on_unwind: BlockId,
},
Assert {
assert: Assert,
target: BlockId,
on_unwind: BlockId,
},
Panic {
name: Name,
on_unwind: BlockId,
},
UnwindTerminate,
UnwindResume,
Return,
UndefinedBehavior,
}Variants
Goto
Switch
Call
Drop
Drop the value at the given place.
Depending on DropKind, this may be a real call to drop_glue, or a conditional call
that should only happen if the place has not been moved out of. See the docs of DropKind
for more details; to get precise drops use --precise-drops.
Fields
InlineAsm
An inline assembly block.
Fields
fallthrough: Option<BlockId>Next block if the control-flow continues without jumping. Absent for naked_asm! and noreturn.
labels: IndexVec<BranchId, BlockId>Targets of AsmOperand::Label operands.
Assert
Assert that the given condition holds, and if not, unwind to the given block. This is used for bounds checks, overflow checks, etc.
Panic
Call to a built-in panicking function.
UnwindTerminate
Unwinding must stop for ABI reasons or because cleanup code panicked again.
UnwindResume
Unwind out of the current function into its caller.
Return
UndefinedBehavior
Reaching this point is undefined behavior in the Rust abstract machine.
Implementations
Sourceimpl TerminatorKind
impl TerminatorKind
pub fn is_goto(&self) -> bool
pub fn is_switch(&self) -> bool
pub fn is_call(&self) -> bool
pub fn is_drop(&self) -> bool
pub fn is_inline_asm(&self) -> bool
pub fn is_assert(&self) -> bool
pub fn is_panic(&self) -> bool
pub fn is_unwind_terminate(&self) -> bool
pub fn is_unwind_resume(&self) -> bool
pub fn is_return(&self) -> bool
pub fn is_undefined_behavior(&self) -> bool
Sourceimpl TerminatorKind
impl TerminatorKind
pub fn as_goto(&self) -> Option<&BlockId>
pub fn as_switch(&self) -> Option<(&SwitchData, &IndexVec<BranchId, BlockId>)>
pub fn as_call(&self) -> Option<(&Call, &BlockId, &BlockId)>
pub fn as_drop(&self) -> Option<(&DropKind, &Place, &FnPtr, &BlockId, &BlockId)>
pub fn as_inline_asm( &self, ) -> Option<(&InlineAsm, &Option<BlockId>, &IndexVec<BranchId, BlockId>, &BlockId)>
pub fn as_assert(&self) -> Option<(&Assert, &BlockId, &BlockId)>
pub fn as_panic(&self) -> Option<(&Name, &BlockId)>
pub fn as_unwind_terminate(&self) -> Option<()>
pub fn as_unwind_resume(&self) -> Option<()>
pub fn as_return(&self) -> Option<()>
pub fn as_undefined_behavior(&self) -> Option<()>
Sourceimpl TerminatorKind
impl TerminatorKind
pub fn as_goto_mut(&mut self) -> Option<&mut BlockId>
pub fn as_switch_mut( &mut self, ) -> Option<(&mut SwitchData, &mut IndexVec<BranchId, BlockId>)>
pub fn as_call_mut(&mut self) -> Option<(&mut Call, &mut BlockId, &mut BlockId)>
pub fn as_drop_mut( &mut self, ) -> Option<(&mut DropKind, &mut Place, &mut FnPtr, &mut BlockId, &mut BlockId)>
pub fn as_inline_asm_mut( &mut self, ) -> Option<(&mut InlineAsm, &mut Option<BlockId>, &mut IndexVec<BranchId, BlockId>, &mut BlockId)>
pub fn as_assert_mut( &mut self, ) -> Option<(&mut Assert, &mut BlockId, &mut BlockId)>
pub fn as_panic_mut(&mut self) -> Option<(&mut Name, &mut BlockId)>
pub fn as_unwind_terminate_mut(&mut self) -> Option<()>
pub fn as_unwind_resume_mut(&mut self) -> Option<()>
pub fn as_return_mut(&mut self) -> Option<()>
pub fn as_undefined_behavior_mut(&mut self) -> Option<()>